import React, { FC, ReactNode } from 'react';
import { StyleProp, TextStyle, ViewStyle } from 'react-native';
export type Modal<P> = {
    Component?: FC<P>;
    id: string;
    props?: Partial<P>;
    style?: {
        body?: StyleProp<ViewStyle>;
        container?: StyleProp<ViewStyle>;
        title?: StyleProp<TextStyle>;
        title_wrapper?: StyleProp<ViewStyle>;
        wrapper?: StyleProp<ViewStyle>;
    };
    title?: string | ReactNode;
};
export type ModalId = Modal<any>['id'];
export type ModalContextType = {
    close: (modalId: ModalId) => void;
    open: <P>(modalId: ModalId, modal?: Partial<Modal<P>>) => void;
    opened: ModalId[];
    register: <P>(modal: Modal<P>) => void;
    registered: Record<ModalId, Modal<any>>;
    unregister: (modalId: ModalId) => void;
};
export declare const ModalContext: React.Context<ModalContextType>;
export declare const ModalProvider: FC<{
    children: ReactNode;
}>;
export declare const openModal: (modal: Modal<any>) => void;
export declare const closeModal: (modalId: ModalId) => void;
